@@ -58,6 +58,7 @@ from alchemite_apiclient.model.dataset import Dataset
 from alchemite_apiclient.model.dataset1 import Dataset1
 from alchemite_apiclient.model.dataset_calculated_columns import DatasetCalculatedColumns
 from alchemite_apiclient.model.dataset_chunk import DatasetChunk
+from alchemite_apiclient.model.dataset_favourite_query import DatasetFavouriteQuery
 from alchemite_apiclient.model.dataset_or_data import DatasetOrData
 from alchemite_apiclient.model.dataset_patch import DatasetPatch
 from alchemite_apiclient.model.dataset_query import DatasetQuery
@@ -67,6 +68,7 @@ from alchemite_apiclient.model.dataset_query_request_sort import DatasetQueryReq
 from alchemite_apiclient.model.dataset_query_response import DatasetQueryResponse
 from alchemite_apiclient.model.dataset_query_response_result import DatasetQueryResponseResult
 from alchemite_apiclient.model.dataset_sharing import DatasetSharing
+from alchemite_apiclient.model.datasets_favourites_filters import DatasetsFavouritesFilters
 from alchemite_apiclient.model.datasets_metadata_filters import DatasetsMetadataFilters
 from alchemite_apiclient.model.datasets_metadata_sort import DatasetsMetadataSort
 from alchemite_apiclient.model.dependent_col_fn_arg_col import DependentColFnArgCol
@@ -92,6 +94,8 @@ from alchemite_apiclient.model.get_all_opt_jobs import GetAllOptJobs
 from alchemite_apiclient.model.get_optimize_done import GetOptimizeDone
 from alchemite_apiclient.model.get_optimize_done_all_of import GetOptimizeDoneAllOf
 from alchemite_apiclient.model.get_optimize_done_consistent import GetOptimizeDoneConsistent
+from alchemite_apiclient.model.get_optimize_done_consistent_resultless import GetOptimizeDoneConsistentResultless
+from alchemite_apiclient.model.get_optimize_done_consistent_resultless_all_of import GetOptimizeDoneConsistentResultlessAllOf
 from alchemite_apiclient.model.get_optimize_failed import GetOptimizeFailed
 from alchemite_apiclient.model.get_optimize_failed_all_of import GetOptimizeFailedAllOf
 from alchemite_apiclient.model.get_optimize_failed_consistent import GetOptimizeFailedConsistent
@@ -103,6 +107,8 @@ from alchemite_apiclient.model.get_optimize_pending_all_of import GetOptimizePen
 from alchemite_apiclient.model.get_optimize_pending_consistent import GetOptimizePendingConsistent
 from alchemite_apiclient.model.get_suggest_additional_done import GetSuggestAdditionalDone
 from alchemite_apiclient.model.get_suggest_additional_done_all_of import GetSuggestAdditionalDoneAllOf
+from alchemite_apiclient.model.get_suggest_additional_done_resultless import GetSuggestAdditionalDoneResultless
+from alchemite_apiclient.model.get_suggest_additional_done_resultless_all_of import GetSuggestAdditionalDoneResultlessAllOf
 from alchemite_apiclient.model.get_suggest_additional_failed import GetSuggestAdditionalFailed
 from alchemite_apiclient.model.get_suggest_additional_failed_all_of import GetSuggestAdditionalFailedAllOf
 from alchemite_apiclient.model.get_suggest_additional_pending import GetSuggestAdditionalPending
@@ -111,6 +117,7 @@ from alchemite_apiclient.model.get_suggest_additional_running import GetSuggestA
 from alchemite_apiclient.model.get_suggest_additional_running_all_of import GetSuggestAdditionalRunningAllOf
 from alchemite_apiclient.model.get_suggest_historic_done import GetSuggestHistoricDone
 from alchemite_apiclient.model.get_suggest_historic_done_all_of import GetSuggestHistoricDoneAllOf
+from alchemite_apiclient.model.get_suggest_historic_done_resultless import GetSuggestHistoricDoneResultless
 from alchemite_apiclient.model.get_suggest_historic_failed import GetSuggestHistoricFailed
 from alchemite_apiclient.model.get_suggest_historic_pending import GetSuggestHistoricPending
 from alchemite_apiclient.model.get_suggest_historic_running import GetSuggestHistoricRunning
@@ -139,8 +146,10 @@ from alchemite_apiclient.model.inline_response2002 import InlineResponse2002
 from alchemite_apiclient.model.inline_response2003 import InlineResponse2003
 from alchemite_apiclient.model.inline_response2004 import InlineResponse2004
 from alchemite_apiclient.model.int_cat_arr import IntCatArr
+from alchemite_apiclient.model.job_favourite_query import JobFavouriteQuery
 from alchemite_apiclient.model.job_patch import JobPatch
 from alchemite_apiclient.model.job_query import JobQuery
+from alchemite_apiclient.model.jobs_favourites_filters import JobsFavouritesFilters
 from alchemite_apiclient.model.jobs_metadata_filters import JobsMetadataFilters
 from alchemite_apiclient.model.jobs_metadata_sort import JobsMetadataSort
 from alchemite_apiclient.model.load_request import LoadRequest
@@ -237,6 +246,8 @@ from alchemite_apiclient.model.project_sharing import ProjectSharing
 from alchemite_apiclient.model.query_request import QueryRequest
 from alchemite_apiclient.model.query_response import QueryResponse
 from alchemite_apiclient.model.range import Range
+from alchemite_apiclient.model.resultless_suggest_additional_job import ResultlessSuggestAdditionalJob
+from alchemite_apiclient.model.resultless_suggest_historic_job import ResultlessSuggestHistoricJob
 from alchemite_apiclient.model.si_sample_def_categorical import SISampleDefCategorical
 from alchemite_apiclient.model.si_sample_definition import SISampleDefinition
 from alchemite_apiclient.model.sample_def_categorical import SampleDefCategorical
@@ -247,6 +258,8 @@ from alchemite_apiclient.model.sample_def_continuous import SampleDefContinuous
 from alchemite_apiclient.model.sample_def_continuous_with_start import SampleDefContinuousWithStart
 from alchemite_apiclient.model.sample_def_discrete import SampleDefDiscrete
 from alchemite_apiclient.model.sample_def_integer import SampleDefInteger
+from alchemite_apiclient.model.sample_def_set import SampleDefSet
+from alchemite_apiclient.model.sample_def_set_string import SampleDefSetString
 from alchemite_apiclient.model.sample_def_start_prop import SampleDefStartProp
 from alchemite_apiclient.model.sample_def_weighted_categorical import SampleDefWeightedCategorical
 from alchemite_apiclient.model.sample_definition import SampleDefinition
