@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import csv
 
 import pandas as pd
@@ -35,7 +33,9 @@ dataset_name = "adrenergic"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
